@@ -119,6 +119,11 @@ def set_svg_background_images(lecture_tex, verbose=False,
     else:
         cdir = os.getcwd()
         os.chdir(os.path.dirname(lecture_tex_nosvg))
+
+        from slider import latexmk
+        print("Compiling latex file using latexmk...", os.path.basename(lecture_tex_nosvg))
+        latexmk(os.path.basename(lecture_tex_nosvg))
+
         execute_command(("latexmk -shell-escape -f -pdf -interaction=nonstopmode " + os.path.basename(lecture_tex_nosvg)).split(" "))
         os.chdir(cdir)
         cache_update_file(MAIN_TEX_DIR, lecture_tex_nosvg)
